@@ -1,4 +1,4 @@
-<TeXmacs|1.99.9>
+<TeXmacs|1.99.11>
 
 <style|<tuple|source|std>>
 
@@ -229,7 +229,9 @@
     </padded>
   </macro>>
 
-  <drd-props|ornamented-titled|arity|2|accessible|all>
+  <drd-props|ornamented|arity|1|accessible|all|locals|<attrs>>
+
+  <drd-props|ornamented-titled|arity|2|accessible|all|locals|<attrs>>
 
   <assign|ornament-indent|<\macro|left|right|bottom|top|body>
     <\with|old-shape|<value|ornament-shape>|old-color|<value|ornament-color>|old-hpadding|<value|ornament-hpadding>|old-vpadding|<value|ornament-vpadding>|old-border|<value|ornament-border>|ornament-shape|classic|ornament-color|#fff0|ornament-hpadding|<tuple|<arg|left>|<arg|right>>|ornament-vpadding|<tuple|<arg|bottom>|<arg|top>>|ornament-border|0ln>
@@ -253,6 +255,8 @@
 
   <assign|ornament-render-body|<macro|body|<arg|body>>>
 
+  <assign|ornament-render-extra|<macro|body|<arg|body>>>
+
   \;
 
   <assign|decorated-hook|<macro|body|<with|bg-color|<value|ornament-extra-color>|old-color|<value|color>|old-math-color|<value|math-color>|old-strong-color|<value|strong-color>|<ornament-render-title|<with|ornament-extra-color|<value|bg-color>|color|<value|old-color>|math-color|<value|old-math-color>|strong-color|<value|old-strong-color>|<with|bg-color|<value|ornament-color>|<ornament-render-body|<with|ornament-color|<value|bg-color>|<arg|body>>>>>>>>>
@@ -261,30 +265,40 @@
 
   <assign|decorated-body|<macro|body|<ornament-render-body|<arg|body>>>>
 
+  <assign|decorated-extra|<macro|body|<ornament-render-extra|<arg|body>>>>
+
   \;
 
-  <assign|decorated|<macro|body|<decorated-hook|<ornament|<decorated-body|<arg|body>>>>>>
+  <assign|decorated|<macro|body|<decorated-hook|<decorated-extra|<ornament|<decorated-body|<arg|body>>>>>>>
 
   <assign|decorated-block|<\macro|body>
-    <decorated-hook|<\ornament>
+    <decorated-hook|<decorate-extra|<\ornament>
       <\wide-normal>
         <\decorated-body>
           <arg|body>
         </decorated-body>
       </wide-normal>
-    </ornament>>
+    </ornament>>>
   </macro>>
 
-  <assign|decorated-titled|<macro|name|body|<decorated-hook|<ornament|<decorated-body|<arg|body>>|<decorated-title|<arg|name>>>>>>
+  <assign|decorated-titled|<macro|name|body|<decorated-hook|<decorated-extra|<ornament|<decorated-body|<arg|body>>|<decorated-title|<arg|name>>>>>>>
 
   <assign|decorated-titled-block|<\macro|name|body>
-    <decorated-hook|<\ornament>
+    <decorated-hook|<decorated-extra|<\ornament>
       <\wide-normal>
         <decorated-body|<arg|body>>
       </wide-normal>
-    </ornament|<decorated-title|<arg|name>>>>
+    </ornament|<decorated-title|<arg|name>>>>>
   </macro>>
 
+  <drd-props|decorated|arity|1|accessible|all|locals|<attrs>>
+
+  <drd-props|decorated-block|arity|1|accessible|all|locals|<attrs>>
+
+  <drd-props|decorated-titled|arity|2|accessible|all|locals|<attrs>>
+
+  <drd-props|decorated-titled-block|arity|2|accessible|all|locals|<attrs>>
+
   <\active*>
     <\src-comment>
       Indentation.
@@ -407,6 +421,8 @@
 
   <assign|space-separated|<xmacro|items|<arg|items|0><map-args|prepend-space|concat|items|1>>>
 
+  <assign|document-bis|<xmacro|items|<map-args|identity|document|items>>>
+
   <assign|font-magnify|<macro|factor|body|<with|font-size|<times|<value|font-size>|<arg|factor>>|<arg|body>>>>
 
   <assign|hidden-title|<macro|title|>>
