@@ -304,7 +304,8 @@
   (:check-mark "*" test-default-font?)
   (init-default "font")
   (init-default "math-font")
-  (init-default "font-family"))
+  (init-default "font-family")
+  (remove-font-packages))
 
 (menu-bind document-short-chinese-font-menu
   (if (font-exists-in-tt? "AppleGothic")
@@ -603,7 +604,7 @@
 (menu-bind page-rendering-menu
   ("Paper" (init-page-rendering "paper"))
   ("Papyrus" (init-page-rendering "papyrus"))
-  ("Automatic" (init-page-rendering "automatic"))
+  ("Screen" (init-page-rendering "automatic"))
   ("Beamer" (init-page-rendering "beamer"))
   ("Book" (init-page-rendering "book"))
   ("Panorama" (init-page-rendering "panorama")))
@@ -626,6 +627,13 @@
       ---
       ("Portrait" (init-page-orientation "portrait"))
       ("Landscape" (init-page-orientation "landscape")))
+  (-> "Crop marks"
+      ("Default" (init-default "page-crop-marks"))
+      ---
+      ("None" (init-env "page-crop-marks" ""))
+      ("A3" (init-env "page-crop-marks" "a3"))
+      ("A4" (init-env "page-crop-marks" "a4"))
+      ("Letter" (init-env "page-crop-marks" "letter")))
   (-> "Margins"
       ("Default" (init-default "page-width-margin" "page-height-margin"
                                "page-odd" "page-even" "page-right"
@@ -819,7 +827,7 @@
            (!= (get-init-tree "sectional-short-style") (tree 'macro "false")))
       (-> "Part" (link document-part-menu)))
   (-> "Source"
-      ("Edit source tree" (toggle-preamble))
+      ("Edit source tree" (toggle-source-mode))
       ---
       (group "Preferences")
       (link document-source-preferences-menu))
@@ -852,7 +860,7 @@
            (!= (get-init-tree "sectional-short-style") (tree 'macro "false")))
       (-> "Part" (link document-part-menu)))
   (-> "Source"
-      ("Edit source tree" (toggle-preamble))
+      ("Edit source tree" (toggle-source-mode))
       ("Preferences" (open-source-tree-preferences)))
   (-> "Update" (link document-update-menu))
   ---
@@ -892,6 +900,65 @@
 (tm-menu (focus-document-extra-menu t))
 (tm-menu (focus-style-extra-menu t))
 
+(menu-bind cite-texmacs-only-menu
+  ("TeXmacs website" (cite-texmacs "TeXmacs:website"))
+  ("TeXmacs manual" (cite-texmacs "TeXmacs:manual")))
+
+(menu-bind cite-texmacs-related-menu
+  (-> "Tutorials"
+      ("GNU TeXmacs: a scientific editing platform"
+       (cite-texmacs "TeXmacs:vdH2:2006"))
+      ("TeXmacs in 60 minutes"
+       (cite-texmacs "TeXmacs:Seidl:2003"))
+      ("TeXmacs Quick-Start Guide"
+       (cite-texmacs "TeXmacs:Ratier:2005")))
+  (-> "Surveys"
+      ("GNU TeXmacs (ASCM 2005)"
+       (cite-texmacs "TeXmacs:vdH:2005"))
+      ("GNU TeXmacs (Dagstuhl 2006)"
+       (cite-texmacs "TeXmacs:vdH1:2006"))
+      ("GNU TeXmacs: a scientific editing platform"
+       (cite-texmacs "TeXmacs:HGGLPR:2012"))
+      ("GNU TeXmacs: Towards a Scientific Office Suite"
+       (cite-texmacs "TeXmacs:GHPR:2014")))      
+  (-> "Research papers"
+      ("GNU TeXmacs, a free, structured, wysiwyg and technical text editor"
+       (cite-texmacs "TeXmacs:vdH:2001"))
+      ("Conservative conversion between LeaTeX and TeXmacs"
+       (cite-texmacs "TeXmacs:HP:2014"))
+      ("Towards semantic mathematical editing"
+       (cite-texmacs "TeXmacs:vdH:2015"))
+      ("Preserving syntactic correctness while editing mathematical formulas"
+       (cite-texmacs "TeXmacs:HLR:2015"))
+      ("Mathematical Font Art"
+       (cite-texmacs "TeXmacs:vdH:2016")))
+  (-> "Plug-ins"
+      ("TeXmacs interfaces to Maxima, Mupad and Reduce"
+       (cite-texmacs "TeXmacs:Grozin:2001"))
+      ("TeXmacs-Maxima interface"
+       (cite-texmacs "TeXmacs:Grozin:2005"))
+      ("TeXmacs-Reduce interface"
+       (cite-texmacs "TeXmacs:Grozin:2012"))
+      ("TeXmacs as an authoring tool for formal developments"
+       (cite-texmacs "TeXmacs:AR:2004"))
+      ("A Document-Oriented Coq Plugin for TeXmacs"
+       (cite-texmacs "TeXmacs:MG:2006"))))
+
+(menu-bind cite-texmacs-menu
+  (group "Acknowledge")
+  ("Written with TeXmacs" (acknowledge-texmacs))
+  ---
+  (group "Cite")
+  (link cite-texmacs-only-menu)
+  ---
+  (group "Cite related work")
+  (link cite-texmacs-related-menu))
+
+(menu-bind cite-texmacs-short-menu
+  (link cite-texmacs-only-menu)
+  ---
+  (link cite-texmacs-related-menu))
+
 (tm-menu (focus-style-menu t)
   (group "Style")
   (let* ((st* (get-style-list))
@@ -950,6 +1017,7 @@
   (dynamic (focus-style-menu t))
   ---
   (dynamic (focus-document-menu t))
+  (-> "Cite TeXmacs" (link cite-texmacs-menu))
   (dynamic (focus-document-extra-menu t))
   ---
   ("Help" (focus-help)))
@@ -979,7 +1047,9 @@
         ("Other package" (interactive add-style-package)))
     (assuming (tree-is-buffer? t)
       ((balloon (icon "tm_focus_help.xpm") "Describe tag")
-       (focus-help)))))
+       (focus-help)))
+    (=> (balloon (icon "tm_like.xpm") "Cite TeXmacs")
+        (link cite-texmacs-menu))))
 
 (define (is-background-picture? bg*)
   (with bg (tm->stree bg*)
@@ -992,7 +1062,7 @@
   (with setter (lambda (col) (init-env-tree "bg-color" col))
     (assuming (not (is-background-picture? (get-init-tree "bg-color")))
       (dynamic (focus-customizable-icons-item
-                setter "bg-color" "Background color")))
+                "bg-color" "Background color" :global)))
     (assuming (is-background-picture? (get-init-tree "bg-color"))
       ((balloon (icon "tm_camera.xpm") "Select background picture")
        (with bg (tree->stree (get-init-tree "bg-color"))
@@ -1013,7 +1083,8 @@
     (=> (balloon (eval (upcase-first (get-init "page-type")))
                  "Paper size")
         (link document-page-size-menu))
-    (=> (balloon (eval (upcase-first (font-family-main (get-init "font"))))
+    (=> (balloon (eval `(verbatim ,(upcase-first
+                                    (font-family-main (get-init "font")))))
                  "Main document font")
         (link document-short-font-menu))
     (=> (balloon (eval (string-append (get-init "font-base-size") "pt"))
