@@ -29,18 +29,23 @@
     "<lflux>" "<gflux>")
 
   (define Models-symbol
-    (:type infix)
+    (:type prefix-infix)
     (:spacing default wide)
     "<models>"
-    "<vdash>" "<dashv>" "<vDash>" "<Dashv>"
-    "<Vdash>" "<dashV>" "<VDash>" "<DashV>"
-    "<Vvdash>" "<dashVv>" "<VvDash>" "<DashVv>"
-    "<longvdash>" "<longdashv>" "<longvDash>" "<longDashv>"
-    "<longVdash>" "<longdashV>" "<longVDash>" "<longDashV>"
-    "<longVvdash>" "<longdashVv>" "<longVvDash>" "<longDashVv>"
-    "<nvdash>" "<ndashv>" "<nvDash>" "<nDashv>"
-    "<nVdash>" "<ndashV>" "<nVDash>" "<nDashV>"
-    "<nVvdash>" "<ndashVv>" "<nVvDash>" "<nDashVv>")
+    "<vdash>" "<vDash>" "<Vdash>" "<VDash>" "<Vvdash>" "<VvDash>"
+    "<longvdash>" "<longvDash>"
+    "<longVdash>" "<longVDash>"
+    "<longVvdash>" "<longVvDash>"
+    "<nvdash>" "<nvDash>" "<nVdash>" "<nVDash>" "<nVvdash>" "<nVvDash>")
+
+  (define Modeled-symbol
+    (:type infix)
+    (:spacing default wide)
+    "<dashv>" "<Dashv>" "<dashV>" "<DashV>" "<dashVv>" "<DashVv>"
+    "<longdashv>" "<longDashv>"
+    "<longdashV>" "<longDashV>"
+    "<longdashVv>" "<longDashVv>"
+    "<ndashv>" "<nDashv>" "<ndashV>" "<nDashV>" "<ndashVv>" "<nDashVv>")
 
   (define Quantifier-symbol
     (:type prefix)
@@ -52,7 +57,8 @@
     (:spacing wide wide)
     "<implies>" "<equivalent>" "<Leftarrow>" "<Rightarrow>" "<Leftrightarrow>"
     "<Longleftarrow>" "<Longrightarrow>" "<Longleftrightarrow>"
-    "<Lleftarrow>" "<Rrightarrow>"
+    "<Llongleftarrow>" "<Llongrightarrow>" "<Llongleftrightarrow>"
+    "<Lleftarrow>" "<Rrightarrow>" "<LRleftrightarrow>"
     "<nLeftarrow>" "<nRightarrow>" "<nLeftrightarrow>")
 
   (define Imply-lim-symbol
@@ -88,7 +94,8 @@
     (:penalty 20)
     (:spacing wide wide)
 
-    "=" "<ne>" "<neq>" "<longequal>" "<less>" "<gtr>" "<le>" "<leq>"
+    "=" "<ne>" "<neq>" "<longequal>" "<longequiv>"
+    "<less>" "<gtr>" "<le>" "<leq>"
     "<prec>" "<preceq>" "<preceqq>" "<ll>" "<lleq>" "<subset>" "<subseteq>"
     "<sqsubset>" "<sqsubseteq>" "<sqsubseteqq>" "<in>" "<ni>" "<of>"
     "<ge>" "<geq>" "<succ>" "<succeq>" "<succeqq>"
@@ -171,7 +178,7 @@
     (:penalty 20)
     (:spacing wide wide)
     (:limits always)
-    "<equallim>" "<longequallim>")
+    "<equallim>" "<longequallim>" "<longequivlim>")
 
   (define Relation-symbol
     Relation-nolim-symbol Relation-lim-symbol)
@@ -200,6 +207,8 @@
     "<longdownharpoonleft>" "<longdownharpoonright>"
     "<leftarrowtail>" "<leftleftarrows>" "<leftrightarrows>"
     "<longleftleftarrows>" "<longleftrightarrows>"
+    "<longthreeleftarrows>" "<longthreerightarrows>"
+    "<longfourleftarrows>" "<longfourrightarrows>"
     "<leftrightharpoons>" "<rightleftharpoons>"
     "<longleftrightharpoons>" "<longrightleftharpoons>"
     "<looparrowleft>" "<looparrowright>" "<Lsh>"
@@ -211,7 +220,9 @@
     "<Rsh>" "<twoheadleftarrow>" "<twoheadrightarrow>"
     "<upharpoonleft>" "<upharpoonright>"
     "<longupharpoonleft>" "<longupharpoonright>"
-    "<upuparrows>" "<leftrightmap>" "<pointer>")
+    "<upuparrows>" "<leftrightmap>" "<pointer>"
+    "<threeleftarrows>" "<threerightarrows>"
+    "<fourleftarrows>" "<fourrightarrows>")
   
   (define Arrow-lim-symbol
     (:type infix)
@@ -221,7 +232,9 @@
     "<leftarrowlim>" "<rightarrowlim>" "<leftrightarrowlim>"
     "<longleftarrowlim>" "<longrightarrowlim>" "<longleftrightarrowlim>"
     "<mapstolim>" "<longmapstolim>"
-    "<leftsquigarrowlim>" "<rightsquigarrowlim>" "<leftrightsquigarrowlim>")
+    "<leftsquigarrowlim>" "<rightsquigarrowlim>" "<leftrightsquigarrowlim>"
+    "<longleftleftarrowslim>" "<longleftrightarrowslim>"
+    "<longrightleftarrowslim>" "<longrightrightarrowslim>")
 
   (define Arrow-symbol
     Arrow-nolim-symbol Arrow-lim-symbol)
@@ -245,14 +258,14 @@
     "<setminus>" "<smallsetminus>" "<bslash>")
 
   (define Plus-visible-symbol
-    (:type infix)
+    (:type prefix-infix)
     (:penalty 30)
     (:spacing default default)
     "+" "<amalg>" "<oplus>" "<boxplus>"
     "<dotplus>" "<dotamalg>" "<dotoplus>" "<pplus>")
 
   (define Plus-invisible-symbol
-    (:type infix)
+    (:type prefix-infix)
     (:penalty invalid)
     (:spacing none default)
     "<noplus>")
@@ -267,7 +280,7 @@
     "<upl>")
 
   (define Minus-symbol
-    (:type infix)
+    (:type prefix-infix)
     (:penalty 30)
     (:spacing default default)
     "-" "<pm>" "<mp>" "<minus>" "<longminus>"
@@ -738,6 +751,7 @@
   (define Infix-symbol
     Assign-symbol
     Models-symbol
+    Modeled-symbol
     Imply-symbol
     Or-symbol
     And-symbol
@@ -756,4 +770,12 @@
     :<frac :<sqrt :<wide :<table :<row
     :<around :<around* :<big-around :<left :<mid :<right :<big
     :<lsub :<lsup :<rsub :<rsup :<lprime :<rprime
-    :<Prefix :<Postfix))
+    :<Prefix :<Postfix)
+
+  (attach-macro
+    ("<ldots>" low-dots)
+    ("<cdots>" center-dots)
+    ("<hdots>" high-dots)
+    ("<vdots>" vertical-dots)
+    ("<ddots>" diagonal-dots)
+    ("<udots>" upward-dots)))
